@@ -14,6 +14,21 @@
   );
 {%- endmacro %}
 
+{% macro postgres__get_create_index_sql(relation, index_dict) -%}
+  {%- set index_config = adapter.parse_index(index_dict) -%}
+  {%- set comma_separated_columns = ", ".join(index_config.columns) -%}
+  {%- set index_name = index_config.render(relation) -%}
+
+  create {% if index_config.unique -%}
+    unique
+  {%- endif %} index if not exists
+  "{{ index_name }}"
+  on {{ relation }} {% if index_config.type -%}
+    using {{ index_config.type }}
+  {%- endif %}
+  ({{ comma_separated_columns }});
+{%- endmacro %}
+
 {% macro postgres__create_schema(relation) -%}
   {% if relation.database -%}
     {{ adapter.verify_database(relation.database) }}
@@ -165,7 +180,8 @@
 
 
 {% macro postgres__alter_column_comment(relation, column_dict) %}
-  {% for column_name in column_dict %}
+  {% set existing_columns = adapter.get_columns_in_relation(relation) | map(attribute="name") | list %}
+  {% for column_name in column_dict if (column_name in existing_columns) %}
     {% set comment = column_dict[column_name]['description'] %}
     {% set escaped_comment = postgres_escape_comment(comment) %}
     comment on column {{ relation }}.{{ adapter.quote(column_name) if column_dict[column_name]['quote'] else column_name }} is {{ escaped_comment }};
